---
type: docs
title: Autoconfiguração do IPv6
---

Há três métodos principais para a atribuição de IPv6s:

* Atribuição manual, configurando cada máquina com um endereço.
* Por meio de um servidor *com estado* DHCPv6.
* Através da configuração *sem estado* [SLAAC (*Stateless Address Auto-Configuration*)](https://www.rfc-editor.org/rfc/rfc4862).

No C3SL, adotamos a configuração sem estado SLAAC e [devido aos avanços na
especificação dos protocolos](https://www.rfc-editor.org/rfc/rfc8106),
é perfeitamente possível configurar servidores DNS e listas de busca DNS.
Ao invés de um servidor DHCPv6, é necessário um servidor de anúncio de roteador
IPv6 [como o encontrado na máquina roble](/docs/services/roble-radvd).

O processo para uma máquina obter um endereço IPv6 segue da seguinte maneira:

1. Um endereço link-local é configurado usando o MAC da interface
criando um endereço com prefixo `fe80::`.
2. É verificado se existe um endereço idêntico na rede através de um
processado chamado de *Duplicate Address Detection* (DAD).
3. A máquina manda uma mensagem de solicitação de roteador (RS) usando ICMPv6
perguntando qual o prefixo global a ser utilizado.
4. O servidor de anúncio de roteador IPv6 responde com um anúncio de roteador (RA)
que inclui o prefixo global a ser utilizado.
5. O IPv6 é configurado concatenando o prefixo recebido pelo roteador
ao início do seu endereço.

Observe que o resultado é que cada máquina configurada assim tem obrigatoriamente
dois endereços IPv6: um link-local e outro global. Você pode verificar isso bem
ao verificar a interface rede:

```console
root@docs:~# ip address show ens18
2: ens18: <BROADCAST,MULTICAST,UP,LOWER_UP> mtu 1500 qdisc pfifo_fast state UP group default qlen 1000
    link/ether 00:16:cc:aa:00:72 brd ff:ff:ff:ff:ff:ff
    altname enp0s18
    inet 200.236.31.191/25 brd 200.236.31.255 scope global dynamic ens18
       valid_lft 2118811sec preferred_lft 2118811sec
    inet6 2801:82:80ff:8002:216:ccff:feaa:72/64 scope global dynamic mngtmpaddr
       valid_lft 85636sec preferred_lft 13636sec
    inet6 fe80::216:ccff:feaa:72/64 scope link
       valid_lft forever preferred_lft forever
```

Neste caso, o endereço link-local (indicado pelo `link`) é `fe80::216:ccff:feaa:72`
e o endereço global é `2801:82:80ff:8002:216:ccff:feaa:72`.
