---
type: docs
title: Domain Name System
---

O *Domain Name System* é um protocolo que implementa um
[serviço de diretório ou de nomes](servico-diretorio) utilizado primariamente para traduzir
nomes para endereços IP.
[A tirinha *How DNS works*](https://howdns.works/ep1/) explica bem o
funcionamento geral do DNS. No C3SL, o [servidor de DNS primário fica
na urquell](/docs/services/urquell-dns) e o [servidor de DNS secundário
fica na sagres](/docs/services/sagres-dns).

## Arquivos de zona

Arquivos de zona são especificados na [RFC 1035 seção 5](https://datatracker.ietf.org/doc/html/rfc1035#section-5).

## Transferências de zona

Transferências de zona são um tipo de transação de DNS que é geralmente
denotada pelo tipo de consulta `AXFR`. Elas são utilizadas principalmente
para replicação do DNS autoritativo, tendo seu uso na rede do C3SL na replicação
da [servidora de DNS autoritativa primária](/docs/services/urquell-dns) com a
[servidora de DNS autoritativa secundária](/docs/services/sagres-dns).
Qualquer pedido de transferência vindo de outras máquinas deve ser rejeitado,
pois pode levar a ataques.

Diferente do UDP utilizado pelo DNS, a transferência de zona ocorre via TCP,
pois os arquivos de zona geralmente são muito grandes para caber em pacotes
únicos. E o mecanismo principal para descobrir se é necessário fazer uma
atualização é o serial encontrado no registro de começo de autoridade (SOA).
O serial é visto como para frente ou para trás através da
[aritmética de serial](https://datatracker.ietf.org/doc/html/rfc1982).
O método utilizado para o serial é o recomendado na
[RFC 1912 seção 2.2](https://datatracker.ietf.org/doc/html/rfc1912#section-2.2)
que consiste em manter o padrão `YYYYMMDDNN`, onde N é um número de revisão que
é incrementado que não é para dar problema até o ano 4294 (já que é um número de 32 bits).

## Registros de cola

[Registros de cola](https://datatracker.ietf.org/doc/html/rfc8499#section-7)
são registros de DNS de servidores de nome nas subzonas colocados na seção de
registros adicionais. Eles são tema do [episódio bônus da tirinha *How DNS
works*](https://howdns.works/ep7/) e servem principalmente para descobrir o IP
dos servidores de nomes de um determinado domínio, o que geralmente tem uma
dependência cíclica: para descobrir o IP de `dnsimple.com` é necessário falar
com o servidor `ns.dnsimple.com`, mas de nada adianta se você não sabe o IP dele.

Um exemplo é o nome `c3sl.ufpr.br`. A AGTIC (que possui os servidores de
nome `ns.ufpr.br` e `ns2.ufpr.br`) coloca registros de cola para dizer
que o DNS primário `ns.c3sl.ufpr.br` fica no IPv4 `200.17.202.3` e IPv6
`2801:82:80ff:8001::2` e que o DNS secundário `ns2.c3sl.ufpr.br`
fica no IPv4 `200.236.31.1` e IPv6 `2801:82:80ff:8000::2`, observe (alguns
detalhes omitidos por brevidade):

```console
$ dig +trace +additional +yaml urquell.c3sl.ufpr.br
-
  type: MESSAGE
  message:
    type: AUTH_RESPONSE
    response_address: "2001:500:2f::f"
    response_message_data:
      opcode: QUERY
      AUTHORITY_SECTION:
        - br. 172800 IN NS a.dns.br.
        - br. 172800 IN NS b.dns.br.
        - br. 172800 IN NS c.dns.br.
        - br. 172800 IN NS d.dns.br.
        - br. 172800 IN NS e.dns.br.
        - br. 172800 IN NS f.dns.br.
      ADDITIONAL_SECTION:
        - a.dns.br. 172800 IN A 200.219.148.10
        - a.dns.br. 172800 IN AAAA 2001:12f8:6::10
        - b.dns.br. 172800 IN A 200.189.41.10
        - b.dns.br. 172800 IN AAAA 2001:12f8:8::10
        - c.dns.br. 172800 IN A 200.192.233.10
        - c.dns.br. 172800 IN AAAA 2001:12f8:a::10
        - d.dns.br. 172800 IN A 200.219.154.10
        - d.dns.br. 172800 IN AAAA 2001:12f8:4::10
        - e.dns.br. 172800 IN A 200.229.248.10
        - e.dns.br. 172800 IN AAAA 2001:12f8:2::10
        - f.dns.br. 172800 IN A 200.219.159.10
        - f.dns.br. 172800 IN AAAA 2001:12f8:c::10
-
  type: MESSAGE
  message:
    type: AUTH_RESPONSE
    response_address: "200.189.41.10"
    response_message_data:
      opcode: QUERY
      AUTHORITY_SECTION:
        - ufpr.br. 3600 IN NS ns.ufpr.br.
        - ufpr.br. 3600 IN NS ns2.ufpr.br.
      ADDITIONAL_SECTION:
        - ns2.ufpr.br. 3600 IN A 200.17.209.123
        - ns.ufpr.br. 3600 IN A 200.17.209.1
        - ns2.ufpr.br. 3600 IN AAAA 2801:82:8020:0:8377:0:209:2
        - ns.ufpr.br. 3600 IN AAAA 2801:82:8020:0:8377:0:209:1
-
  type: MESSAGE
  message:
    type: AUTH_RESPONSE
    response_address: "2801:82:8020:0:8377:0:209:2"
    response_message_data:
      opcode: QUERY
      AUTHORITY_SECTION:
        - c3sl.ufpr.br. 3600 IN NS ns.c3sl.ufpr.br.
        - c3sl.ufpr.br. 3600 IN NS ns2.c3sl.ufpr.br.
      ADDITIONAL_SECTION:
        - ns.c3sl.ufpr.br. 3600 IN AAAA 2801:82:80ff:8001::2
        - ns2.c3sl.ufpr.br. 3600 IN AAAA 2801:82:80ff:8000::2
        - ns.c3sl.ufpr.br. 3600 IN A 200.17.202.3
        - ns2.c3sl.ufpr.br. 3600 IN A 200.236.31.1
-
  type: MESSAGE
  message:
    type: AUTH_RESPONSE
    response_address: "200.17.202.3"
    response_message_data:
      opcode: QUERY
      ANSWER_SECTION:
        - urquell.c3sl.ufpr.br. 3600 IN A 200.17.202.3
      AUTHORITY_SECTION:
        - c3sl.ufpr.br. 3600 IN NS ns.c3sl.ufpr.br.
        - c3sl.ufpr.br. 3600 IN NS ns2.c3sl.ufpr.br.
      ADDITIONAL_SECTION:
        - ns.c3sl.ufpr.br. 3600 IN A 200.17.202.3
        - ns2.c3sl.ufpr.br. 3600 IN A 200.236.31.1
        - ns.c3sl.ufpr.br. 3600 IN AAAA 2801:82:80ff:8001::2
        - ns2.c3sl.ufpr.br. 3600 IN AAAA 2801:82:80ff:8000::2
```
