---
type: docs
title: ZFS
---

The Z File System (ZFS) é um sistema de arquivos robusto originado do
sistema operacional Unix Solaris. A sua maior funcionalidade é
que ele é focado em integridade de dados através da proteção dos dados
dos usuários no disco contra corrupção silenciosa dos dados causada pela
degradação de dados, quedas de energia, bugs em firmware de discos, entre outros
[^cite_sun2012] [^cite_freebsd2024].

Este sistema de arquivos pode trabalhar com RAID em hardware, mas geralmente
ele é mais eficiente e tem mais garantias de proteção de dados se ele tiver
acesso total a todos os dispositivos de armazenamento. Assim, ele provê um
sistema de RAID em software chamado RAIDZ [^cite_openzfsraidz2024].
Existem cinco diferentes modos de RAIDZ:

- Stripe, similar ao RAID 0, escrevendo em sequência, sem redundância.
- Mirror, similar ao RAID 1, permitindo que todos os discos menos um falhe
  através de cópias totais dos dados.
- RAIDZ1, similar ao RAID 5 que utiliza dados de paridade que são mais eficientes,
  permitindo que um disco falhe, exigindo pelo menos três discos.
- RAIDZ2, similar ao RAID 6 que utiliza dados de paridade, permitindo que dois
  discos falhem, exigindo pelo menos quatro discos.
- RAIDZ3, similar ao RAID 7 que utiliza dados de paridade, permitindo que três
  discos falhem, exigindo pelo menos cinco discos.

Um *pool* do ZFS é essencialmente um disco lógico criado através da combinação
de um ou mais discos físicos.

## Obtendo informações

Um dos comandos que podemos utilizar para obter informações do ZFS é o `zpool`,
e `zpool status` nos dá exatamente qual nível de RAIDZ e quais discos fazem
parte de cada *pool* do ZFS:

```console
duvel:~# zpool status
  pool: tank
 state: ONLINE
  scan: scrub repaired 0B in 1 days 22:36:16 with 0 errors on Mon Jan 15 23:00:17 2024
config:

        NAME                        STATE     READ WRITE CKSUM
        tank                        ONLINE       0     0     0
          raidz2-0                  ONLINE       0     0     0
            wwn-0x5000c500d8a69593  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888ebe3  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888fe33  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d88901df  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888e67b  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d8a694a3  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888fe0b  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d8a6959b  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d8890bf7  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888bc57  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888ca7f  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888c3eb  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888b47b  ONLINE       0     0     0  (non-allocating)
            wwn-0x5000c500d888c38b  ONLINE       0     0     0  (non-allocating)

errors: No known data errors
```

{{< alert title="Nota" >}}
Estar mostrando `(non-allocating)` é aparentemente [um bug que deve se
resolver na próxima vez que a máquina reiniciar](https://discourse.practicalzfs.com/t/meaning-of-non-allocating-in-zpool-status/1029).
{{< /alert >}}

Outra informação interessante pode ser do tamanho total, alocado e livre de
cada *pool* do ZFS, que pode ser obtido pelo `zpool list`:

```console
duvel:~# zpool list
NAME   SIZE  ALLOC   FREE  CKPOINT  EXPANDSZ   FRAG    CAP  DEDUP    HEALTH  ALTROOT
tank   102T  76.9T  25.0T        -         -    39%    75%  1.00x    ONLINE  -
```

Cada *pool* do ZFS pode ser usada para montar ou mais sistema de arquivos
na máquina, para obter informações sobre eles, podemos usar o comando `zfs list`:

```console
duvel:~# zfs list -t all
NAME                          USED  AVAIL  REFER  MOUNTPOINT
tank                         63.0T  20.4T   236K  /tank
tank/backup                  63.0T  20.4T  45.6T  /backup
tank/backup@pre_restauracao  17.4T      -  42.2T  -
```

Aqui também vemos mais do que um sistema de arquivos, temos uma *snapshot*. Uma
*snapshot* é uma fotografia do sistema de arquivos no tempo. Inicialmente ela
tem os mesmos arquivos contidos naquilo que ela referencia e ocupa
zero espaço lógico para armazenar, esse é o montante mostrado em `REFER`.
Conforme a origem muda, a *snapshot* começa a ocupar espaço adicional para
manter os arquivos originais, e este é o montante em `USED`.

Podemos ver detalhes de uma determinada *snapshot* foi criada através do comando
`zfs get`:

```console
duvel:~# zfs get -s none all tank/backup@pre_restauracao
NAME                         PROPERTY              VALUE                  SOURCE
tank/backup@pre_restauracao  type                  snapshot               -
tank/backup@pre_restauracao  creation              Mon Oct 16  9:37 2023  -
tank/backup@pre_restauracao  used                  17.4T                  -
tank/backup@pre_restauracao  referenced            42.2T                  -
tank/backup@pre_restauracao  compressratio         1.65x                  -
tank/backup@pre_restauracao  createtxg             3083253                -
tank/backup@pre_restauracao  version               5                      -
tank/backup@pre_restauracao  utf8only              off                    -
tank/backup@pre_restauracao  normalization         none                   -
tank/backup@pre_restauracao  casesensitivity       sensitive              -
tank/backup@pre_restauracao  guid                  16039213187972211706   -
tank/backup@pre_restauracao  defer_destroy         off                    -
tank/backup@pre_restauracao  userrefs              0                      -
tank/backup@pre_restauracao  objsetid              67483                  -
tank/backup@pre_restauracao  refcompressratio      1.65x                  -
tank/backup@pre_restauracao  written               42.2T                  -
tank/backup@pre_restauracao  logicalreferenced     63.0T                  -
```

Uma *snapshot* pode ser usada para reverter o sistema de arquivos para o estado
da *snapshot*.

## Gerenciamento

Todos os comandos feitos que mexem com os *pools* do ZFS podem ser vistos através
do comando `zpool history`:

```console
duvel:~# zpool history
History for 'tank':
2023-04-10.03:24:02 zpool create -f tank -m /tank raidz2 wwn-0x5000c500d8a69593 wwn-0x5000c500d888ebe3 wwn-0x5000c500d888fe33 wwn-0x5000c500d88901df wwn-0x5000c500d888e67b wwn-0x5000c500d8a694a3 wwn-0x5000c500d888fe0b wwn-0x5000c500d8a6959b wwn-0x5000c500d8890bf7 wwn-0x5000c500d888bc57 wwn-0x5000c500d888ca7f wwn-0x5000c500d888c3eb wwn-0x5000c500d888b47b wwn-0x5000c500d888c38b
2023-04-10.03:25:05 zfs create tank/backup
2023-04-10.03:27:08 zfs set mountpoint=/backup_denovo/ tank/backup
2023-04-10.03:27:51 zfs set compression=lz4 tank/backup
2023-05-03.22:18:59 zfs set mountpoint=/backup tank/backup
2023-05-07.07:01:51 zpool scrub tank
2023-05-23.16:53:08 zfs set compression=lz4 tank/backup
2023-06-02.19:56:30 zpool import -c /etc/zfs/zpool.cache -aN
2023-10-08.00:24:04 zpool scrub tank
2023-10-10.11:57:44 zpool import -c /etc/zfs/zpool.cache -aN
2023-10-16.09:37:54 zfs snapshot tank/backup@pre_restauracao
2024-01-14.00:24:05 zpool scrub tank
2024-01-14.00:30:51 zpool clear tank
```

O ZFS não usa a ferramenta `fsck` para reparar o sistema de arquivos. Ao invés
disso ele vem com uma ferramenta de `scrub` que regularmente examina os dados
e arruma corrupções silenciosas dos dados, mas que pode ser executada manualmente
através do `zpool scrub`.

Outro comando disponível é o `zpool clear` que serve para limpar erros de
dispositivos físicos em uma determinada *pool* do ZFS. A ideia é que o *pool*
vai parar em caso de algum erro de hardware. O hardware deve então ser avaliado
e arrumado pelos administradores de sistema. Após a avaliação, e com o hardware
problemático fora da máquina, o ZFS pode retomar o serviço após um
`zpool clear`.

{{< alert title="TODO" >}}
Seções de criação, importação e remoção de pools e sistemas de arquivos.
{{< /alert >}}

[^cite_sun2012]: Oracle Solaris ZFS Administration Guide: What Is ZFS?. 2012. URL: <https://docs.oracle.com/cd/E23823_01/html/819-5461/zfsover-2.html>.

[^cite_freebsd2024]: FreeBSD Handbook: The Z File System (ZFS). 2024. URL: <https://docs.freebsd.org/en/books/handbook/zfs/>.

[^cite_openzfsraidz2024]: OpenZFS Documentation: RAIDZ. 2024. URL: <https://openzfs.github.io/openzfs-docs/Basic%20Concepts/RAIDZ.html>.
