---
type: docs
title: Como adicionar discos no Ceph
tags: [ceph]
---

## Como trocar disco

1. Identifique o disco falhado:

   ```console
   $ ceph health
   $ ceph osd tree | grep -i down
   ```

2. Pare o daemon do disco:

   ```console
   $ systemctl stop ceph-osd@OSD_ID
   ```

3. Tire o OSD do Ceph:

   ```console
   $ ceph osd out OSD_ID
   $ ceph osd crush remove osd.OSD_ID
   ```

4. Remova o disco do Ceph:

   ```console
   $ ceph osd rm osd.OSD_ID
   ```

5. Desmonte o disco:

   ```console
   $ umount /var/lib/ceph/osd/$CLUSTER_NAME-$OSD_ID
   ```

6. Remova do LVM, primeiro achando o disco e a partição do SSD correspondente a ele.

   Por exemplo, para remover do LVM OSD.0, primeiro ache o OSD.0 no LVM:

   ```console
   barril4:~# ceph-volume lvm list


   ====== osd.0 =======

     [db]          /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-ea40e801-188f-4d53-afdb-6082eb5e8185

         block device              /dev/ceph-a75e7b96-ddb4-4838-8e98-777c1492dab5/osd-block-5b0842c7-ee56-4d05-8bb2-00efdb475b04
         block uuid                FDPpBc-cvOG-JZYq-5D6u-2RlJ-56gz-1LUncO
         cephx lockbox secret
         cluster fsid              c30ecc8d-440e-4608-b3fe-5020337ae11d
         cluster name              ceph
         crush device class        None
         db device                 /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-ea40e801-188f-4d53-afdb-6082eb5e8185
     db uuid                   rN0LG9-86Dl-KgzQ-DUOd-hF9u-A3Kl-nLdwV2
     encrypted                 0
         osd fsid                  5b0842c7-ee56-4d05-8bb2-00efdb475b04
         osd id                    0
         osdspec affinity
         type                      db
         vdo                       0
         devices                   /dev/nvme0n1

     [block]       /dev/ceph-a75e7b96-ddb4-4838-8e98-777c1492dab5/osd-block-5b0842c7-ee56-4d05-8bb2-00efdb475b04

         block device              /dev/ceph-a75e7b96-ddb4-4838-8e98-777c1492dab5/osd-block-5b0842c7-ee56-4d05-8bb2-00efdb475b04
         block uuid                FDPpBc-cvOG-JZYq-5D6u-2RlJ-56gz-1LUncO
         cephx lockbox secret
         cluster fsid              c30ecc8d-440e-4608-b3fe-5020337ae11d
         cluster name              ceph
         crush device class        None
         db device                 /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-ea40e801-188f-4d53-afdb-6082eb5e8185
         db uuid                   rN0LG9-86Dl-KgzQ-DUOd-hF9u-A3Kl-nLdwV2
         encrypted                 0
         osd fsid                  5b0842c7-ee56-4d05-8bb2-00efdb475b04
         osd id                    0
         osdspec affinity
         type                      block
         vdo                       0
         devices                   /dev/sdc
   ```

   Agora remova o `block` e o `db`.

   1. No caso do DB precisa remover tando do `ceph-volume`, quanto excluir
      a partição do SSD. O comando `ceph-volume lvm zap` remove do Ceph e
      o `lvremove` remove a partição do SSD:

      ```console
      $ ceph-volume lvm zap /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-ea40e801-188f-4d53-afdb-6082eb5e8185
      $ lvremove /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-ea40e801-188f-4d53-afdb-6082eb5e8185
      ```

   2. Para remover o bloco execute:

      ```console
      $ ceph-volume lvm zap /dev/ceph-a75e7b96-ddb4-4838-8e98-777c1492dab5/osd-block-5b0842c7-ee56-4d05-8bb2-00efdb475b04
      ```

## Inconsistências em PGs

Para descobrir quais PGs estão inconsistentes rode o seguinte comando:

```console
$ ceph health detail
```

Exemplo:

```console
root@urquell:~# ceph health detail
HEALTH_ERR 2 scrub errors; Possible data damage: 1 pg inconsistent
[ERR] OSD_SCRUB_ERRORS: 2 scrub errors
[ERR] PG_DAMAGED: Possible data damage: 1 pg inconsistent
    pg 2.8a is active+clean+scrubbing+deep+inconsistent+repair, acting [21,14,19]
```

O PG de id 2.7a está inconsistente.

Antes de executar o comando é necessário rodar o `deep-scrub` para o PGs,
para poder popular a lista de inconsistências.

Para listar as inconsistências no RADOS faça:

```console
$ rados list-inconsistent-obj <pg_id> --format=json-pretty
{
    "epoch": 30350,
    "inconsistents": []
}
```

Onde:

- \<pg_id> é o id do PGs que você está investigando

Se a lista `inconsistents` estiver vazio, como no exemplo, é porque o
PGs está limpo, sem inconsistências.

Exemplo de quando está limpo:

```console
root@urquell:~# rados list-inconsistent-obj 2.8a --format=json-pretty
{
    "epoch": 30350,
    "inconsistents": []
}
```

Exemplo de quando tem coisas inconsistentes:

```console
root@urquell:~# rados list-inconsistent-obj 2.1c9 --format=json-pretty
{
    "epoch": 32839,
    "inconsistents": [
        {
            "object": {
                "name": "rbd_data.66927f86465d81.000000000005f05e",
                "nspace": "",
                "locator": "",
                "snap": "head",
                "version": 8980407
            },
            "errors": [],
            "union_shard_errors": [
                "read_error"
            ],
            "selected_object_info": {
                "oid": {
                    "oid": "rbd_data.66927f86465d81.000000000005f05e",
                    "key": "",
                    "snapid": -2,
                    "hash": 4245014473,
                    "max": 0,
                    "pool": 2,
                    "namespace": ""
                },
                "version": "33515'8980407",
                "prior_version": "33515'8980406",
                "last_reqid": "client.37607010.0:1285973",
                "user_version": 8980407,
                "size": 4194304,
                "mtime": "2022-01-12T16:16:37.032935-0300",
                "local_mtime": "2022-01-12T16:16:37.038382-0300",
                "lost": 0,
                "flags": [
                    "dirty",
                    "omap_digest"
                ],
                "truncate_seq": 0,
                "truncate_size": 0,
                "data_digest": "0xffffffff",
                "omap_digest": "0xffffffff",
                "expected_object_size": 4194304,
                "expected_write_size": 4194304,
                "alloc_hint_flags": 0,
                "manifest": {
                    "type": 0
                },
                "watchers": {}
            },
            "shards": [
                {
                    "osd": 14,
                    "primary": false,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0x9d509e56"
                },
                {
                    "osd": 36,
                    "primary": true,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0x9d509e56"
                },
                {
                    "osd": 41,
                    "primary": false,
                    "errors": [
                        "read_error"
                    ],
                    "size": 4194304
                }
            ]
        },
        {
            "object": {
                "name": "rbd_data.66927f86465d81.000000000005f12f",
                "nspace": "",
                "locator": "",
                "snap": "head",
                "version": 8980408
            },
            "errors": [],
            "union_shard_errors": [
                "read_error"
            ],
            "selected_object_info": {
                "oid": {
                    "oid": "rbd_data.66927f86465d81.000000000005f12f",
                    "key": "",
                    "snapid": -2,
                    "hash": 429430217,
                    "max": 0,
                    "pool": 2,
                    "namespace": ""
                },
                "version": "33515'8980408",
                "prior_version": "16199'2274056",
                "last_reqid": "client.37607010.0:1286037",
                "user_version": 8980408,
                "size": 4194304,
                "mtime": "2022-01-12T16:16:42.187861-0300",
                "local_mtime": "2022-01-12T16:16:42.202694-0300",
                "lost": 0,
                "flags": [
                    "dirty",
                    "data_digest",
                    "omap_digest"
                ],
                "truncate_seq": 0,
                "truncate_size": 0,
                "data_digest": "0xabd012a0",
                "omap_digest": "0xffffffff",
                "expected_object_size": 4194304,
                "expected_write_size": 4194304,
                "alloc_hint_flags": 0,
                "manifest": {
                    "type": 0
                },
                "watchers": {}
            },
            "shards": [
                {
                    "osd": 14,
                    "primary": false,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0xabd012a0"
                },
                {
                    "osd": 36,
                    "primary": true,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0xabd012a0"
                },
                {
                    "osd": 41,
                    "primary": false,
                    "errors": [
                        "read_error"
                    ],
                    "size": 4194304
                }
            ]
        }
    ]
}
```

Para reparar um Pgs inconsistente faça:

```console
$ ceph pg repair <pg_id>
```

Onde:

- \<pg_id>: é o id do PGs que você quer reparar

Exemplo:

```console
root@urquell:~# ceph pg repair 2.8a
instructing pg 2.8a on osd.21 to repair
```

Outra alternativa é fazer o `deep-scrub` no PGs que tá inconsistente.

Para rodar deep-scrub em um pgs faça:

```console
$ ceph pg deep-scrub <pg_id>
```

Onde:

- \<pg_id>: é o id do PGs a ser executado o deep-scrub

É necessário rodar o `deep-scrub` para poder diagnosticar inconsistências
nos PGs. Exemplo:

```console
root@urquell:~# ceph pg deep-scrub 2.8a
instructing pg 2.8a on osd.21 to deep-scrub
```

## Como identificar qual disco de virtual está inconsistente

Precisa identificar qual pgs é o inconsistente, olhe a seção anterior
para saber como identificar e daí rode o comando:

```console
$ rados list-inconsistent-obj <pgs_id> --format=json-pretty
```

Exemplo:

```console
root@urquell:~/ceph# rados list-inconsistent-obj 2.1c9 --format=json-pretty
{
    "epoch": 32839,
    "inconsistents": [
        {
            "object": {
                "name": "rbd_data.66927f86465d81.000000000005f05e",
                "nspace": "",
                "locator": "",
                "snap": "head",
                "version": 8980407
            },
            "errors": [],
            "union_shard_errors": [
                "read_error"
            ],
            "selected_object_info": {
                "oid": {
                    "oid": "rbd_data.66927f86465d81.000000000005f05e",
                    "key": "",
                    "snapid": -2,
                    "hash": 4245014473,
                    "max": 0,
                    "pool": 2,
                    "namespace": ""
                },
                "version": "33515'8980407",
                "prior_version": "33515'8980406",
                "last_reqid": "client.37607010.0:1285973",
                "user_version": 8980407,
                "size": 4194304,
                "mtime": "2022-01-12T16:16:37.032935-0300",
                "local_mtime": "2022-01-12T16:16:37.038382-0300",
                "lost": 0,
                "flags": [
                    "dirty",
                    "omap_digest"
                ],
                "truncate_seq": 0,
                "truncate_size": 0,
                "data_digest": "0xffffffff",
                "omap_digest": "0xffffffff",
                "expected_object_size": 4194304,
                "expected_write_size": 4194304,
                "alloc_hint_flags": 0,
                "manifest": {
                    "type": 0
                },
                "watchers": {}
            },
            "shards": [
                {
                    "osd": 14,
                    "primary": false,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0x9d509e56"
                },
                {
                    "osd": 36,
                    "primary": true,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0x9d509e56"
                },
                {
                    "osd": 41,
                    "primary": false,
                    "errors": [
                        "read_error"
                    ],
                    "size": 4194304
                }
            ]
        },
        {
            "object": {
                "name": "rbd_data.66927f86465d81.000000000005f12f",
                "nspace": "",
                "locator": "",
                "snap": "head",
                "version": 8980408
            },
            "errors": [],
            "union_shard_errors": [
                "read_error"
            ],
            "selected_object_info": {
                "oid": {
                    "oid": "rbd_data.66927f86465d81.000000000005f12f",
                    "key": "",
                    "snapid": -2,
                    "hash": 429430217,
                    "max": 0,
                    "pool": 2,
                    "namespace": ""
                },
                "version": "33515'8980408",
                "prior_version": "16199'2274056",
                "last_reqid": "client.37607010.0:1286037",
                "user_version": 8980408,
                "size": 4194304,
                "mtime": "2022-01-12T16:16:42.187861-0300",
                "local_mtime": "2022-01-12T16:16:42.202694-0300",
                "lost": 0,
                "flags": [
                    "dirty",
                    "data_digest",
                    "omap_digest"
                ],
                "truncate_seq": 0,
                "truncate_size": 0,
                "data_digest": "0xabd012a0",
                "omap_digest": "0xffffffff",
                "expected_object_size": 4194304,
                "expected_write_size": 4194304,
                "alloc_hint_flags": 0,
                "manifest": {
                    "type": 0
                },
                "watchers": {}
            },
            "shards": [
                {
                    "osd": 14,
                    "primary": false,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0xabd012a0"
                },
                {
                    "osd": 36,
                    "primary": true,
                    "errors": [],
                    "size": 4194304,
                    "omap_digest": "0xffffffff",
                    "data_digest": "0xabd012a0"
                },
                {
                    "osd": 41,
                    "primary": false,
                    "errors": [
                        "read_error"
                    ],
                    "size": 4194304
                }
            ]
        }
    ]
}
```

O OID é `"name": "rbd_data.66927f86465d81.000000000005f12f"`.
Pegue até o segundo ponto, no caso `rbd_data.66927f86465d81`.
Aí, para identificar qual disco pertence o bloco identificado execute:

```bash
for image in $(rbd ls); do
    result=`rbd info ${image}| grep <rbd_data>`
    if [[ $? -eq 0 ]]; then
        rbd info ${image}
    fi
done;
```

Exemplo:

```console
root@urquell:~/ceph# for image in $(rbd ls); do \
        result=`rbd info ${image} | grep "rbd_data.66927f86465d81"` \
        if [[ $? -eq 0 ]]; then \
                rbd info ${image} \
        fi \
done
rbd image 'vm-170-disk-1':
        size 2.1 TiB in 563200 objects
        order 22 (4 MiB objects)
        snapshot_count: 0
        id: 66927f86465d81
        block_name_prefix: rbd_data.66927f86465d81
        format: 2
        features: layering, exclusive-lock, object-map, fast-diff, deep-flatten
        op_features:
        flags:
        create_timestamp: Sat Oct 16 13:34:12 2021
        access_timestamp: Sun Jan 16 18:36:40 2022
        modify_timestamp: Sun Jan 16 18:36:37 2022
root@urquell:~/ceph#
```

Por fim, agora que identificou o disco que pertence o bloco, basta ir no
Proxmox e achar em qual máquina virtual está esse disco. No exemplo, é a
máquina virtual de id 170 disco 2, o `/home` da bbbprod.

## Como adicionar discos

Para adicionar um disco, garanta que ele não tenha nenhuma partição primeiro:

```console
$ sgdisk -Z /dev/sda
```

Então, adicione:

```console
$ ceph-volume lvm create --data /dev/sda --block.db /dev/nvme0n1 --block.db-slots 16
```

### Comandos úteis

Para mostrar todos os OSDs use um dos seguintes comandos:

```console
$ ceph osd df # lista
$ ceph osd tree # árvore
```

O comando `ceph osd df` é útil para ver o balanceamento dos discos.

Para mostrar o estado do Ceph faça:

```console
$ ceph status
```

Para saber detalhadamente o que tá acontecendo use:

```console
$ ceph health
```

### Pegar todos os seriais dos discos usados no Ceph

```bash
for i in $(ceph-volume lvm list | grep "/dev/sd" | awk -F" " '{print $2}'); do
    echo -n $i ;
    smartctl -i $i | grep -i "serial" | cut -d':' -f2;
done;
```

Exemplo:

```console
barril2:~# for i in $(ceph-volume lvm list | grep "/dev/sd" | awk -F" " '{print $2}'); do \
    echo -n $i ; \
    smartctl -i $i | grep -i "serial" | cut -d':' -f2; \
done;

/dev/sdt    ZA15V0J9
/dev/sdu    ZA161LHJ
/dev/sdw    ZA16X2KA
/dev/sdx    ZA161L54
/dev/sdv    ZA15ZGFP
barril2:~#
```

### Pegar todos os UIDs dos discos usados no Ceph

```bash
for i in $(ceph-volume lvm list | grep "/dev/sd" | awk -F" " '{print $2}' | cut -d'/' -f3); do
    echo -n $i ;
    ls -lah /dev/disk/by-id/ | grep $i | grep wwn;
done;
```

Exemplo:

```console
barril2:~# for i in $(ceph-volume lvm list | grep "/dev/sd" | awk -F" " '{print $2}' | cut -d'/' -f3); do \
    echo -n $i; \
    ls -lah /dev/disk/by-id/ | grep $i | grep wwn; \
done;

sdtlrwxrwxrwx 1 root root    9 Jul 31 13:56 wwn-0x5000c500938f9337 -> ../../sdt
sdulrwxrwxrwx 1 root root    9 Jul 31 13:56 wwn-0x5000c500938ec5fe -> ../../sdu
sdwlrwxrwxrwx 1 root root    9 Jul 31 13:56 wwn-0x5000c500a265cafc -> ../../sdw
sdxlrwxrwxrwx 1 root root    9 Jul 31 13:56 wwn-0x5000c500938f6677 -> ../../sdx
sdvlrwxrwxrwx 1 root root    9 Jul 31 13:56 wwn-0x5000c500938f0559 -> ../../sdv
```

## Como gerenciar discos falhos no Ceph

Se você está aqui, espero que seja porque você tenha recebido alguns alertas do
Zabbix emitidos pelo Ceph Monitor dizendo que alguns OSDs não estão funcionando.
O Ceph tenta ressucitar o disco quando isso acontece, mas se ele permanece
falhando, o que se deve fazer é testar e remover o disco de operação.

1. Primeiro precisamos identificar qual OSD está falhando:

   ```console
   barril4:~/scripts# ceph osd status
   ID  HOST      USED  AVAIL  WR OPS  WR DATA  RD OPS  RD DATA  STATE
    0  barril4  4732G  2836G     11     84.3k      1        0   exists,up
    1  barril4     0      0       2     79.6k      0        0   autoout,exists
    2  barril4  4826G  2741G      5     30.0k      3      228k  exists,up
    3  barril4  4951G  2616G      6     65.3k      0        0   exists,up
   ```

   Observe que o OSD 1 não está `up`.

1. Agora identificamos qual o disco falho:

   ```console
   barril4:~/scripts# ceph-volume lvm list | grep -A 19 '= osd.1 ='
   ====== osd.1 =======

     [db]          /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-2c87d89f-23f3-4c76-b61c-f868c35486bc

         block device              /dev/ceph-e42d4f35-b3d6-4aed-b288-c549d8b70941/osd-block-58e98ed2-a658-44ee-9992-d15f054a7694
         block uuid                JojsTQ-cY4R-fG2y-AAjv-IfDI-3YJT-34XkYA
         cephx lockbox secret
         cluster fsid              c30ecc8d-440e-4608-b3fe-5020337ae11d
         cluster name              ceph
         crush device class        None
         db device                 /dev/ceph-8e43d77e-ebc3-4c7e-9da8-475a37da59ae/osd-db-2c87d89f-23f3-4c76-b61c-f868c35486bc
         db uuid                   s0kw8e-iW38-boMx-9xTV-sXfT-C8Ju-lXkaiH
         encrypted                 0
         osd fsid                  58e98ed2-a658-44ee-9992-d15f054a7694
         osd id                    1
         osdspec affinity
         type                      db
         vdo                       0
         devices                   /dev/sdh

   ```

   Note então que o disco falho é o `/dev/sdh` neste caso.

1. Podemos zerar o disco e verificar se ocorre alguma falha:

   ```console
   barril4:~# dd if=/dev/zero of=/dev/sdh bs=4M oflag=sync status=progress &; \
     dmesg -TW
   ```

   Isso vai demorar bastante, então rode em uma sessão do tmux. Se o `dd` terminar
   a sua execução e o `dmesg` não acusar nenhum erro, o disco ainda é *usável*,
   porém definitivamente suspeito. Zerar o disco arrumou os setores corrompidos
   do disco e o gerenciador do disco conseguiu identificar e realocar os setores
   defeituosos. De toda forma o disco merece uma inspeção com `smartctl`:

   ```console
   barril4:~# smartctl -a /dev/sdh
   smartctl 7.3 2022-02-28 r5338 [x86_64-linux-6.1.0-0.deb11.5-amd64] (local build)
   Copyright (C) 2002-22, Bruce Allen, Christian Franke, www.smartmontools.org

   === START OF INFORMATION SECTION ===
   Vendor:               SEAGATE
   Product:              ST8000NM0075
   Revision:             E002
   Compliance:           SPC-4
   User Capacity:        8,001,563,222,016 bytes [8.00 TB]
   Logical block size:   512 bytes
   Physical block size:  4096 bytes
   LU is fully provisioned
   Rotation Rate:        7200 rpm
   Form Factor:          3.5 inches
   Logical Unit id:      0x5000c50093ff6bc7
   Serial number:        ZA17WQSP0000R742QPZP
   Device type:          disk
   Transport protocol:   SAS (SPL-4)
   Local Time is:        Sun Mar  3 18:04:07 2024 -03
   SMART support is:     Available - device has SMART capability.
   SMART support is:     Enabled
   Temperature Warning:  Enabled

   === START OF READ SMART DATA SECTION ===
   SMART Health Status: DATA CHANNEL IMPENDING FAILURE DATA ERROR RATE TOO HIGH [asc=5d, ascq=32]

   Grown defects during certification <not available>
   Total blocks reassigned during format <not available>
   Total new blocks reassigned = 49200
   Power on minutes since format <not available>
   Current Drive Temperature:     53 C
   Drive Trip Temperature:        60 C

   Accumulated power on time, hours:minutes 52214:46
   Manufactured in week 19 of year 2017
   Specified cycle count over device lifetime:  10000
   Accumulated start-stop cycles:  80
   Specified load-unload count over device lifetime:  300000
   Accumulated load-unload cycles:  4216

   Elements in grown defect list: 49236

   Vendor (Seagate Cache) information
     Blocks sent to initiator = 83987848
     Blocks received from initiator = 354284152
     Blocks read from cache and sent to initiator = 2331500192
     Number of read and write commands whose size <= segment size = 577322949
     Number of read and write commands whose size > segment size = 1980651

   Vendor (Seagate/Hitachi) factory information
     number of hours powered up = 52214.77
     number of minutes until next internal SMART test = 25

   Error counter log:
              Errors Corrected by           Total   Correction     Gigabytes    Total
                  ECC          rereads/    errors   algorithm      processed    uncorrected
              fast | delayed   rewrites  corrected  invocations   [10^9 bytes]  errors
   read:   2826058232    56169         0  2826114401      56169     450842.769           0
   write:         0        0         0         0          0      91089.432           0

   Non-medium error count:     6026


   [GLTSD (Global Logging Target Save Disable) set. Enable Save with '-S on']
   No Self-tests have been logged
   ```

   O que é importante neste diagnóstico é:

   `Transport protocol:`
   : Neste caso `SAS (SPL-4)` que indica se é SATA ou SAS.

   `Accumulated power on time, hours:minutes`
   : Tempo de operação do disco. Ao converter para anos, vemos que esse disco
   está se aproximando da marca dos 6 anos.

   `Manufactured in week {} of year {}`
   : Quando o disco foi fabricado, o que indica de qual lote este disco é,
   não sendo, por exemplo, da leva dos últimos 4 anos na escrita deste guia (2024).

   `Elements in grown defect list:`
   : Quantidade de setores ruins no disco. Se essa quantidade aumentar
   gradualmente, esse disco precisa ser trocado.

   `SMART Health Status:`
   : O estado de erro que o SMART identificou. Neste caso, temos um problema
   de comunicação, onde somas de verificação estão dando errado, indicando
   uma falha iminente.

1. Para retirar o disco, é altamente recomendado utilizar o `ledctl` para piscar
   um LED vermelho no disco correspondente na controladora:

   ```console
   $ ledctl locate /dev/sdh
   $ ledctl locate_off /dev/sdh
   ```
