---
type: docs
title: Como criar o Ceph Object Gateway
tags: [ceph]
---

## Conceitos

- **Realm**: Um realm representa um namespace globalmente exclusivo consistindo em um ou mais zone groups, contendo uma ou mais zonas e zonas, contendo buckets que contêm objetos. Um realm permite que o Ceph Object Gateway suporte vários namespaces e suas configurações no mesmo hardware.
- **Zone Group**: O Ceph Object Gateway oferece suporte a implantações de vários locais e um namespace global usando a noção de zone groups. Um zone group define a localização geográfica de uma ou mais instâncias do Ceph Object Gateway em uma ou mais zonas.
- **Zones**: Uma zona define um grupo lógico que consiste em uma ou mais instâncias do Ceph Object Gateway.
- **Buckets**: Um bucket é um contêiner de objetos.
- **Object**: Os objetos consistem em dados e metadados de objetos. Os metadados são um conjunto de pares nome-valor que descrevem o objeto. Todo objeto está contido em um bucket.

## Criando Ceph Object Gateway

Criar um realm:

```console
$ radosgw-admin realm create --rgw-realm=s3_realm --default
```

Criar um zone group:

```console
$ radosgw-admin zonegroup create --rgw-zonegroup=default  --master --default
```

Cria uma zona:

```console
$ radosgw-admin zone create --rgw-zonegroup=default --rgw-zone=s3 --master --default
```

Para salvar as alterações:

```console
$ radosgw-admin period update --rgw-realm=s3_realm --commit
```

## Criando serviços nos nodos

Instalar radosgw:

```console
$ apt install radosgw
```

Criar o diretório de dados:

```console
$ mkdir -p /var/lib/ceph/radosgw/ceph-rgw.<NODE_NAME>
```

Configure o keyring:

```console
$ ceph auth get-or-create client.rgw.<NODE_NAME> osd 'allow rwx' mon 'allow rw' -o /var/lib/ceph/radosgw/ceph-rgw.<NODE_NAME>/keyring
```

Finalizando:

```console
$ touch /var/lib/ceph/radosgw/ceph-rgw.<NODE_NAME>/done
$ chown -R ceph:ceph /var/lib/ceph/radosgw/
```

Ative o serviço:

```console
$ systemctl enable ceph-radosgw.target
$ systemctl enable ceph-radosgw@rgw.<NODE_NAME>
$ systemctl start ceph-radosgw@rgw.<NODE_NAME>
```
