---
type: docs
title: Como configurar o PAM nos terminais do DINF
tags: [pam]
---

Foi adotado o [guia de referência da RJ Systems](http://www.rjsystems.nl/en/2100-d6-kerberos-openldap-client.php) com algumas
modificações na parte da PAM para ficar o mais semelhante possível com a
configuração da [](/docs/virtuals/mumm).

## Passo 1: Instalar pacotes do Kerberos, LDAP, PAM e afins

O primeiro passo consiste em instalar todos os pacotes necessários:

```console
$ apt install krb5-{config,user} libpam-krb5\
      ldap-utils libnss-ldap libpam-ldap\
      nscd libsasl2-modules-gssapi-mit\
      kstart ecryptfs-utils zsh
```

Durante a instalação será perguntado algumas coisas, o pacote
`libnss-ldap` vai perguntar:

```
LDAP SERVER URI: ldap://urquell
Distinguished name of the search base: dc=C3LOCAL
LDAP version to use: 3
Does the LDAP database require login? No
Special LDAP privileges for root? No
Make the configuration file readable/writeable by its owner only? No
```

O pacote `libpam-ldap` vai fazer as seguintes perguntas:

```
Allow LDAP admin account to behave like local root? No
Does the LDAP database require login?: No
Local encryption algorithm to use for passwords: crypt
Should man and mandb be installed 'setuid man'? No
```

## Passo 2: Configurando o Kerberos

A configuração do Kerberos é muito simples, basta copiar esse arquivo:

```ini
[libdefaults]
    default_realm = C3LOCAL

# The following krb5.conf variables are only for MIT Kerberos.
    krb4_config = /etc/krb.conf
    krb4_realms = /etc/krb.realms
    kdc_timesync = 1
    ccache_type = 4
    forwardable = true
    proxiable = true

# The following encryption type specification will be used by MIT Kerberos
# if uncommented.  In general, the defaults in the MIT Kerberos code are
# correct and overriding these specifications only serves to disable new
# encryption types as they are added, creating interoperability problems.
#
# The only time when you might need to uncomment these lines and change
# the enctypes is if you have local software that will break on ticket
# caches containing ticket encryption types it doesn't know about (such as
# old versions of Sun Java).
    allow_weak_crypto = false
#    default_tgs_enctypes = des3-hmac-sha1
#    default_tkt_enctypes = des3-hmac-sha1
#    permitted_enctypes = des3-hmac-sha1

# The following libdefaults parameters are only for Heimdal Kerberos.
    v4_instance_resolve = false
    v4_name_convert = {
        host = {
            rcmd = host
            ftp = ftp
        }
        plain = {
            something = something-else
        }
    }
    fcc-mit-ticketflags = true

[realms]
    C3LOCAL = {
        kdc = urquell.c3local
        admin_server = urquell.c3local
        default_domain = c3local
        passwd_server = urquell.c3local
    }

[domain_realm]
    .c3local = C3LOCAL
    c3local = C3LOCAL
    .c3sl.ufpr.br = C3LOCAL
    c3sl.ufpr.br = C3LOCAL

[login]
    krb4_convert = true
    krb4_get_tickets = false

[logging]
    default = FILE:/var/log/krb5libs.log
    kdc = FILE:/var/log/krb5kdc.log
    admin_server = FILE:/var/log/kadmind.log
```

Para `/etc/krb5.conf`. É possível testar se o Kerberos está funcional com a
seguinte sequências de comandos:

```console
$ kinit <user>
$ klist
```

Exemplo:

```console
root@cloneimgteste:~# kinit omdj17
Password for omdj17@C3LOCAL:
root@cloneimgteste:~# klist
Ticket cache: FILE:/tmp/krb5cc_0
Default principal: omdj17@C3LOCAL

Valid starting     Expires        Service principal
12/21/20 11:43:39  12/21/20 21:43:39  krbtgt/C3LOCAL@C3LOCAL
    renew until 12/22/20 11:43:24
root@cloneimgteste:~#
```

## Passo 3: Configurando LDAP

Agora temos que configurar o LDAP para se comunicar com o servidor, e exportar
os usuários da base de dados para o sistema. Edite o arquivo
`/etc/nsswitch.conf` e deixe altere os atributos de `passwd`, `group` e
`shadow`:

```
passwd:     compat ldap
group:      compat ldap
shadow:     compat ldap
```

Após terminar a  configuração, reinicie o serviço com `systemctl restart nscd`.

## Passo 4: Configurando PAM

Agora o passo mais complicado que é modificar configurar o PAM para permitir
acesso via Kerberos. A configuração da PAM consiste em editar os seguintes
arquivos:
* `/etc/pam.d/common-auth`
* `/etc/pam.d/common-account`
* `/etc/pam.d/common-password`
* `/etc/pam.d/common-session`
* `/etc/pam.d/common-session-noninteractive`

A configuração desses arquivos não segue de forma fiel o guia de referência e
segue em parte a configuração existente na máquina virtual
[](/pages/virtuals/mumm). Assim, é possível apenas fazer um rsync desses arquivos
da [](/pages/virtuals/mumm) para a imagem dos terminais.

### Arquivo `/etc/pam.d/common-auth`

Edite o arquivo para incluir as seguintes informações:

```
auth     [success=2 default=ignore]           pam_krb5.so minimum_uid=1000
auth     [success=1 default=ignore]           pam_unix.so nullok_secure try_first_pass
auth     requisite                    pam_deny.so
auth     required                     pam_permit.so
```

O arquivo deve ficar desta maneira:

```
#
# /etc/pam.d/common-auth - authentication settings common to all services
#
# This file is included from other service-specific PAM config files,
# and should contain a list of the authentication modules that define
# the central authentication scheme for use on the system
# (e.g., /etc/shadow, LDAP, Kerberos, etc.).  The default is to use the
# traditional Unix authentication mechanisms.
#
# As of pam 1.0.1-6, this file is managed by pam-auth-update by default.
# To take advantage of this, it is recommended that you configure any
# local modules either before or after the default block, and use
# pam-auth-update to manage selection of other modules.  See
# pam-auth-update(8) for details.

# here are the per-package modules (the "Primary" block)
auth    [success=3 default=ignore]  pam_krb5.so minimum_uid=1000
auth    [success=2 default=ignore]  pam_unix.so nullok_secure try_first_pass
#auth   [success=1 default=ignore]  pam_ldap.so use_first_pass
# here's the fallback if no module succeeds
auth    requisite           pam_deny.so
# prime the stack with a positive return value if there isn't one already;
# this avoids us returning an error just because nothing sets a success code
# since the modules above will each just jump around
auth    required            pam_permit.so
# and here are more per-package modules (the "Additional" block)
auth    optional            pam_cap.so
# end of pam-auth-update config
```

### Arquivo `/etc/pam.d/common-account`

Edite o arquivo para incluir as seguintes informações:

```
account  [success=1 new_authtok_reqd=done default=ignore] pam_unix.so
account  requisite                    pam_deny.so
account  required                     pam_permit.so
account  required                     pam_krb5.so minimum_uid=1000
```

O arquivo deve ficar desta maneira:

```
#
# /etc/pam.d/common-account - authorization settings common to all services
#
# This file is included from other service-specific PAM config files,
# and should contain a list of the authorization modules that define
# the central access policy for use on the system.  The default is to
# only deny service to users whose accounts are expired in /etc/shadow.
#
# As of pam 1.0.1-6, this file is managed by pam-auth-update by default.
# To take advantage of this, it is recommended that you configure any
# local modules either before or after the default block, and use
# pam-auth-update to manage selection of other modules.  See
# pam-auth-update(8) for details.
#

# here are the per-package modules (the "Primary" block)
account [success=1 new_authtok_reqd=done default=ignore]    pam_unix.so
#account    [success=1 default=ignore]  pam_ldap.so
# here's the fallback if no module succeeds
account requisite           pam_deny.so
# prime the stack with a positive return value if there isn't one already;
# this avoids us returning an error just because nothing sets a success code
# since the modules above will each just jump around
account required            pam_permit.so
# and here are more per-package modules (the "Additional" block)
account required            pam_krb5.so minimum_uid=1000
# end of pam-auth-update config
# esta configuracao eh importante para criar uma home, quando o nfs falhar
session required            pam_mkhomedir.so skel=/etc/skel/ umask=0077
```

### Arquivo `/etc/pam.d/common-password`

Edite o arquivo para incluir as seguintes informações:

```
password requisite                    pam_krb5.so minimum_uid=1000
password [success=1 default=ignore]           pam_unix.so obscure use_authtok try_first_pass sha512
password requisite                    pam_deny.so
password required                     pam_permit.so
```

O arquivo de configuração deve ficar desta maneira:

```
#
# /etc/pam.d/common-password - password-related modules common to all services
#
# This file is included from other service-specific PAM config files,
# and should contain a list of modules that define the services to be
# used to change user passwords.  The default is pam_unix.

# Explanation of pam_unix options:
#
# The "sha512" option enables salted SHA512 passwords.  Without this option,
# the default is Unix crypt.  Prior releases used the option "md5".
#
# The "obscure" option replaces the old `OBSCURE_CHECKS_ENAB' option in
# login.defs.
#
# See the pam_unix manpage for other options.

# As of pam 1.0.1-6, this file is managed by pam-auth-update by default.
# To take advantage of this, it is recommended that you configure any
# local modules either before or after the default block, and use
# pam-auth-update to manage selection of other modules.  See
# pam-auth-update(8) for details.

# here are the per-package modules (the "Primary" block)
password    [success=3 default=ignore]  pam_krb5.so minimum_uid=1000
password    [success=2 default=ignore]  pam_unix.so obscure use_authtok try_first_pass sha512
password    [success=1 user_unknown=ignore default=die] pam_ldap.so use_authtok try_first_pass
# here's the fallback if no module succeeds
password    requisite           pam_deny.so
# prime the stack with a positive return value if there isn't one already;
# this avoids us returning an error just because nothing sets a success code
# since the modules above will each just jump around
password    required            pam_permit.so
# and here are more per-package modules (the "Additional" block)
password    optional    pam_gnome_keyring.so
# end of pam-auth-update config
```

### Arquivo `/etc/pam.d/common-session`

A configuração desse arquivo na [](/pages/virtuals/mumm) e no guia de referência
adotado difere, então segue como o guia de referência diz para fazer e como
está configurado na [](/pages/virtuals/mumm).

No guia de referência ele está assim:

```
session  [default=1]                  pam_permit.so
session  requisite                    pam_deny.so
session  required                     pam_permit.so
session  optional                     pam_krb5.so minimum_uid=1000
session  required                     pam_unix.so

session  required                     pam_mkhomedir.so
```

Na [](/pages/virtuals/mumm) ele está assim:

```
#
# /etc/pam.d/common-session - session-related modules common to all services
#
# This file is included from other service-specific PAM config files,
# and should contain a list of modules that define tasks to be performed
# at the start and end of sessions of *any* kind (both interactive and
# non-interactive).
#
# As of pam 1.0.1-6, this file is managed by pam-auth-update by default.
# To take advantage of this, it is recommended that you configure any
# local modules either before or after the default block, and use
# pam-auth-update to manage selection of other modules.  See
# pam-auth-update(8) for details.

# here are the per-package modules (the "Primary" block)
session [default=1]         pam_permit.so
# here's the fallback if no module succeeds
session requisite           pam_deny.so
# prime the stack with a positive return value if there isn't one already;
# this avoids us returning an error just because nothing sets a success code
# since the modules above will each just jump around
session required            pam_permit.so
# The pam_umask module will set the umask according to the system default in
# /etc/login.defs and user settings, solving the problem of different
# umask settings with different shells, display managers, remote sessions etc.
# See "man pam_umask".
session optional            pam_umask.so
# and here are more per-package modules (the "Additional" block)
session optional            pam_krb5.so minimum_uid=1000
session required    pam_unix.so
session optional            pam_ldap.so
session optional    pam_systemd.so
session optional    pam_ecryptfs.so unwrap
# end of pam-auth-update config
```

### Arquivo `/etc/pam.d/common-noninteractive`

Edite o arquivo com as seguintes informações:

```
session  [default=1]                  pam_permit.so
session  requisite                    pam_deny.so
session  required                     pam_permit.so
session  optional                     pam_krb5.so minimum_uid=1000
session  required                     pam_unix.so
```

O arquivo deve ficar desta maneira:

```
#
# /etc/pam.d/common-session-noninteractive - session-related modules
# common to all non-interactive services
#
# This file is included from other service-specific PAM config files,
# and should contain a list of modules that define tasks to be performed
# at the start and end of all non-interactive sessions.
#
# As of pam 1.0.1-6, this file is managed by pam-auth-update by default.
# To take advantage of this, it is recommended that you configure any
# local modules either before or after the default block, and use
# pam-auth-update to manage selection of other modules.  See
# pam-auth-update(8) for details.

# here are the per-package modules (the "Primary" block)
session [default=1]         pam_permit.so
# here's the fallback if no module succeeds
session requisite           pam_deny.so
# prime the stack with a positive return value if there isn't one already;
# this avoids us returning an error just because nothing sets a success code
# since the modules above will each just jump around
session required            pam_permit.so
# The pam_umask module will set the umask according to the system default in
# /etc/login.defs and user settings, solving the problem of different
# umask settings with different shells, display managers, remote sessions etc.
# See "man pam_umask".
session optional            pam_umask.so
# and here are more per-package modules (the "Additional" block)
session optional            pam_krb5.so minimum_uid=1000
session required    pam_unix.so
session optional            pam_ldap.so
session optional    pam_ecryptfs.so     unwrap
# end of pam-auth-update config
```

## Passo 4: teste a configuração

Faça `su - <user>` para verificar se o PAM consegue se comunicar com o LDAP e o
LDAP com o servidor. Note que o comando só funciona se tiver um ticket do
Kerberos no cache e acusará usuário inexistente caso o ticket não exista. Por exemplo:

```console
root@cloneimgteste:~# kinit omdj17
>>>>>>> c09e8a1 (add pam howto)
root@cloneimgteste:~# su - omdj17
cloneimgteste% bash
omdj17@cloneimgteste:~$
```
