---
type: docs
title: Como configurar acesso ao IPMI
tags: [ipmi]
---

O padrão adotado para configuração dos parâmetros do IPMI são:

| Parâmetro       | Valor Padrão                                   |
| --------------- | ---------------------------------------------- |
| Usuário         | `<secreto>`                                    |
| Senha           | `<secreto>`                                    |
| Default Gateway | 0.0.0.0                                        |
| Subnet Mask     | 255.255.255.0                                  |
| BMC ARP Control | ARP Responses Enabled, Gratuitous ARP Disabled |

Primeiro instale o `ipmitool` na máquina que deseja configurar o IPMI:

```console
barril1:~# apt install -y ipmitool
```

A configuração do BMC (*baseboard management controller*) consiste em configurar
um usuário para todos os canais do IPMI. Normalmente o BMC possui mais de um
canal e **todos** devem ser configurados.

Primeiro verificamos se o BMC atende requisições, é possível que isso aconteça:

```console
root@c3sldatabase:~# ipmitool shell
Could not open device at /dev/ipmi0 or /dev/ipmi/0 or /dev/ipmidev/0: No such file or directory
```

No melhor dos casos, o BMC só está desativado na BIOS. No pior dos casos, o
BMC parou de responder de vez.

O primeiro passo então deve ser descobrir quantos canais estão presentes no
BMC iterando pelos canais pelo comando `ipmitool channel info`:

```console
[root@torneira2-500IO ~]# ipmitool channel info 1
Channel 0x1 info:
  Channel Medium Type   : 802.3 LAN
  Channel Protocol Type : IPMB-1.0
  Session Support       : multi-session
  Active Session Count  : 0
  Protocol Vendor ID    : 7154
  Volatile(active) Settings
    Alerting            : enabled
    Per-message Auth    : enabled
    User Level Auth     : enabled
    Access Mode         : always available
  Non-Volatile Settings
    Alerting            : enabled
    Per-message Auth    : enabled
    User Level Auth     : enabled
    Access Mode         : always available
[root@torneira2-500IO ~]# ipmitool channel info 2
Channel 0x2 info:
  Channel Medium Type   : 802.3 LAN
  ...
[root@torneira2-500IO ~]# ipmitool channel info 3
Channel 0x3 info:
  Channel Medium Type   : 802.3 LAN
  ...
[root@torneira2-500IO ~]# ipmitool channel info 4
IPMI command failed: Invalid data field in request
Unable to Get Channel Info
```

Neste caso descobrimos que o BMC possui os canais 1-3 que estão conectadas a
rede cabeada. Devemos configurar um usuário para cada uma delas.

## Configuração da rede

Precisamos então configurar **todos** os canais utilizamos o comando
`ipmitool lan set`, configurando o endereço IP da máquina na rede IPMI,
a máscara e o gateway padrão para cada canal:

```console
barril1:~# ipmitool lan set 1 access on
barril1:~# ipmitool lan set 1 ipaddr <ip>
barril1:~# ipmitool lan set 1 netmask 255.255.255.0
barril1:~# ipmitool lan set 1 defgw ipaddr 0.0.0.0
barril1:~# ipmitool lan set 2 access on
barril1:~# ipmitool lan set 2 ipaddr <ip>
barril1:~# ipmitool lan set 2 netmask 255.255.255.0
barril1:~# ipmitool lan set 2 defgw ipaddr 0.0.0.0
...
```

O IP dentro da rede IPMI deve constar no arquivo `/root/ipmi/status_ipmi.md`
da [](/docs/machines/base/duvel).

{{< alert title="TODO" >}}
Confirmar se o IP deve ser assinalado sequencialmente, pegando o primeiro que
estiver disponível.
{{< /alert >}}

## Configuração de usuários

Liste os usuários do BMC com o comando `ipmitool user list 1`:

```console
barril1:~# ipmitool user list 1
ID  Name             Callin  Link Auth  IPMI Msg   Channel Priv Limit
1                    true    false      false      Unknown (0x00)
2   root             true    false      false      Unknown (0x00)
3                    true    false      false      Unknown (0x00)
4                    true    false      false      Unknown (0x00)
5                    true    false      false      Unknown (0x00)
6                    true    false      false      Unknown (0x00)
7                    true    false      false      Unknown (0x00)
8                    true    false      false      Unknown (0x00)
9                    true    false      false      Unknown (0x00)
10                   true    false      false      Unknown (0x00)
```

Todos os usuários são pertencentes ao BMC e não apenas a um canal específico,
porém a lista mostra informações atribuídas a cada usuário em um determinado canal,
e pode listar atributos diferentes dependendo do canal utilizado para listar.

O BMC vem com uma quantidade pré-determinada de usuários, então para configurar
um usuário, precisamos apenas escolher um identificador que não foi
utilizado e alterar seus atributos: nome, senha e permissões.

Para configurar o usuário de `id` 3 usamos o comando
`ipmitool user set name` e o comando `ipmitool user set password` para
definir o usuário e senha respectivamente:

```console
barril1:~# ipmitool user set name 3 usuario
barril1:~# ipmitool user set password 3 senha
Set User Password command successful (user 3)
barril1:~# ipmitool user enable 3
barril1:~# ipmitool user list
ID  Name             Callin  Link Auth  IPMI Msg   Channel Priv Limit
1                    true    false      false      Unknown (0x00)
2   root             true    false      false      Unknown (0x00)
3   usuario          true    false      false      Unknown (0x00)
4                    true    false      false      Unknown (0x00)
5                    true    false      false      Unknown (0x00)
6                    true    false      false      Unknown (0x00)
7                    true    false      false      Unknown (0x00)
8                    true    false      false      Unknown (0x00)
9                    true    false      false      Unknown (0x00)
10                   true    false      false      Unknown (0x00)
```

Agora basta atribuir as permissões do usuário criado para todos os canais.
Por exemplo, no nosso usuário 3:

```console
barril1:~# ipmitool lan set 1 auth ADMIN MD5,PASSWORD
barril1:~# ipmitool channel setaccess 1 3 privilege=4
barril1:~# ipmitool channel setaccess 1 3 link=on
barril1:~# ipmitool channel setaccess 1 3 ipmi=on
```

## Redirecionamento do console para o BMC

É desejável que o console do Linux seja também acessível através do IPMI.
A configuração consiste em configurar o grub para redirecionar o tty para
`ttyS1` e ativar o serviço `serial-getty@ttyS1`.

Primeiro, edite o arquivo `/etc/default/grub` e modifique as linhas:

```bash
GRUB_CMDLINE_LINUX_DEFAULT="quiet "
```

Para:

```bash
GRUB_CMDLINE_LINUX_DEFAULT="quiet console=tty0 console=ttyS1,115200n8"
GRUB_SERIAL_COMMAND="serial --speed=115200 --unit=0 --word=8 --parity=no --stop 1"
```

Note que a segunda linha tem que ser adicionada.

Em seguida, ative o serviço `serial-getty@ttyS1` no systemd:

```console
$ systemctl enable --now serial-getty@ttyS1
```
