---
type: docs
title: Como criar aliases no DNS
tags: [dns]
---

Às vezes é necessário criar um nome externo diferente de um nome interno utilizado
para uma determinada máquina virtual. Outrora, alguém pede para redirecionar
um determinado domínio para outro site.
Podemos atender a este pedido criando registros `CNAME` (*canonical name*)
no [servidor de DNS primário](/pages/services/urquell-dns).
Assim, quando o IP do nome apontado mudar, este registro não ficará
desatualizado.

Antes de pensar em fazer essa mudança, tenha certeza de que não existe
um registro de DNS com esse nome e também que o registro de DNS alvo existe.
Você pode verificar isso com o comando `dig`:

```console
$ dig +noall +answer webmail.c3sl.ufpr.br ANY @ns.c3sl.ufpr.br
$ dig +noall +answer roundcube.c3sl.ufpr.br ANY @ns.c3sl.ufpr.br
roundcube.c3sl.ufpr.br.	3600	IN	A	200.236.31.131
roundcube.c3sl.ufpr.br.	3600	IN	AAAA	2801:82:80ff:8002:216:ccff:feaa:74
```

O primeiro comando que busca o novo nome não deve retornar registros e o
segundo comando que busca o nome para onde se quer apontar deve retornar
registros `A` e `AAAA` (que informam o IPv4 e IPv6 respectivamente)
ou `CNAME` (que informa o próximo nome canônico a se buscar).
Note assim que `CNAME`s podem formar uma lista ligada, porém obviamente
essa lista não pode ser cíclica.

A alteração deve ser feita no arquivo de zona do domíno desejado, os quais
podem ser encontrados no diretório `/etc/bind/` da [](/pages/machines/base/urquell).
O arquivo `c3sl.zone` corresponde ao domínio `c3sl.ufpr.br` e o `inf.zone`
corresponde ao domínio `inf.ufpr.br` por convenção.

Por exemplo, se quisermos redirecionar o `webmail.c3sl.ufpr.br` para a máquina
virtual `roundcube` que fica no nome `roundcube.c3sl.ufpr.br`, podemos
apenas adicionar o seguinte registro de DNS `CNAME` ao arquivo `c3sl.zone`
(que consiste em adicionar uma linha **ao final** do arquivo, antes dos includes):

```zone
webmail CNAME roundcube.c3sl.ufpr.br.
```

Note que o ponto no final é **necessário** para ser um nome absoluto. Se
tirarmos o ponto, ele se torna relativo, o que significa que um registro como
este tem o mesmo significado (pois ambos estão no arquivo `c3sl.zone`):

```zone
webmail CNAME roundcube
```

Observe então que como o registro `CNAME` pode especificar um nome absoluto, podemos
utilizá-lo para redirecionar para nomes que estão fora da esfera dos domínios
do C3SL. Por exemplo, é possível utilizá-lo para "rotear" sites para links externos
sem o uso de um proxy. Note que o site será servido pelo IP do domínio alvo,
sendo necessário configurá-lo para receber as requisições corretamente.

Sempre que possível, coloque um comentário antes do registro adicionado
informando quem realizou a alteração, a data da alteração e o motivo, se não
for muito óbvio. No caso dos arquivos de zona, os comentários de linha
começam com o caractere ponto-e-vírgula `;`:

```zone
; webmail eh o servico, roundcube a implementacao utilizada (2024-02-21, Fernando K)
webmail CNAME roundcube
```

Após a modificação, execute o script `/root/bin/atualiza-dns-dhcp` na
[](/pages/machines/base/urquell) para aplicar as mudanças. Ele vai tratar de
aumentar o serial do DNS (para permitir que o servidor de DNS secundário
possa descobrir que foram feitas mudanças) e reiniciar o servidor de DNS para que
as mudanças sejam aplicadas.

Assim, se você executar o comando `dig` novamente para o novo domínio, obterá
o seu novo `CNAME`:

```console
$ dig +noall +answer webmail.c3sl.ufpr.br ANY @urquell
webmail.c3sl.ufpr.br.	3600	IN	CNAME	roundcube.c3sl.ufpr.br.
```

Note que a criação de certificados SSL para os domínios novos não é feita
de maneira automática. Deve-se seguir os passos para [adicionar outros domínios
ao certificado na duvel](/pages/services/duvel-ssl.md#alterando-a-configuracao).
E depois executar o comando `/root/letsencrypt/getssl <domínio>`
na [](/pages/machines/base/duvel) para atualizar os certificados da máquina
virtual associada.
