---
type: docs
title: Como gerar uma imagem dos pontos de acesso sem fio
---

Os pontos de acesso sem fio gerenciados pelo C3SL são roteadores com
o sistema operacional embarcado OpenWrt. E ao invés de baixar imagens já
construídas do sistema operacional, optamos por compilá-las.
Todos os roteadores suportados pelo OpenWrt estão na
[tabela de hardware do projeto](https://openwrt.org/toh/start), e é
importante descobrir o nome do modelo dentro do OpenWrt.

Cada modelo é associado a um [imagebuilder](https://openwrt.org/docs/guide-user/additional-software/imagebuilder),
sendo que o download do imagebuilder de cada roteador pode ser feita no
[diretório de snapshots do OpenWrt](https://downloads.openwrt.org/snapshots/targets/).

Para esse tutorial será utilizado o AP modelo tplink Archer C7 v5 com o
OpenWrt 21.02.2.

{{< alert title="Nota" >}}
É recomendável compilar com usuário não privilegiado para evitar alguns
*warnings*.
{{< /alert >}}

Em uma servidora Debian ou virtual siga os seguintes passos:

1. Instale as dependências utilizadas para compilar que são os seguintes pacotes:

   - build-essential
   - libncurses5-dev
   - libncursesw5-dev
   - zlib1g-dev
   - gawk
   - git
   - gettext
   - libssl-dev
   - xsltproc
   - rsync
   - wget
   - unzip
   - python

   A instalação é feita através do comando:

   ```console
   $ apt install build-essential libncurses5-dev libncursesw5-dev \
       zlib1g-dev gawk git gettext libssl-dev xsltproc rsync wget unzip python
   ```

2. Obtenha o código-fonte fazendo download do código da build.
   Para o nosso roteador isso pode ser feito através do comando:

   ```console
   $ wget https://downloads.openwrt.org/snapshots/targets/ath79/generic/openwrt-imagebuilder-ath79-generic.Linux-x86_64.tar.xz -O imgbuilder.tar.xz
   ```

3. Extraia o arquivo `imgbuilder.tar.xz`:

   ```console
   $ tar xvf imgbuilder.tar.xz
   ```

4. Dentro do diretório do imgbuilder, devemos agora configurar a imagem.

   {{< alert title="TODO" >}}
   Essa parte está terrivelmente incompleta.
   {{< /alert >}}

   O processo de configurar a imagem consiste em criar o diretório `files` e
   depois copiá-lo para dentro do diretório do `imgbuilder`:

   ```console
   $ cp files imgbuilder
   ```

5. O processo de compilação implica em passar múltiplas flags para o `make`,
   podemos dividir entre duas grandes flags, flag de pacotes e de configuração.

   O primeiro passo é remover da imagem estes pacotes:

   - libiwinfo-lua
   - liblua
   - libubus-lua
   - libuci-lua
   - lua
   - luci
   - luci-app-firewall
   - luci-base
   - luci-lib-ip
   - luci-lib-jsonc
   - luci-lib-nixio
   - luci-mod-admin-full
   - luci-proto-ipv6
   - luci-proto-ppp
   - luci-theme-bootstrap
   - uhttpd
   - uhttpd-mod-ubus
   - odhcpd
   - odhcp6c
   - odhcpd-ipv6only
   - odhcpd6c
   - libip6tc
   - ip6tables
   - dnsmasq
   - kmod-ip6tables
   - kmod-usb-core
   - kmod-usb-ehci
   - kmod-usb-ledtrig-usbport
   - kmod-usb2
   - wpad-mini
   - wpad-basic-wolfssl

   E precisamos adicionar os seguintes pacotes:

   - wpad
   - vnstat

   As flags de configuração para o nosso roteador são:

   ```console
   $ make -j40 image PROFILE=tplink_archer-c7-v5  CONFIG_IPV6=n FILES=files/ PACKAGES=$PACKAGES
   ```

   O `PROFILE=tplink_archer-c7-v5` varia conforme o modelo do *access point*.

   Então para compilar a imagem precisamos executar um `make` com essas opções:

   ```console
   $ make -j40 image PROFILE=tplink_archer-c7-v5 CONFIG_IPV6=n FILES=files/ PACKAGES=\
   -libiwinfo-lua \
   -liblua \
   -libubus-lua \
   -libuci-lua \
   -lua \
   -luci \
   -luci-app-firewall \
   -luci-base \
   -luci-lib-ip \
   -luci-lib-jsonc \
   -luci-lib-nixio \
   -luci-mod-admin-full \
   -luci-proto-ipv6 \
   -luci-proto-ppp \
   -luci-theme-bootstrap \
   -uhttpd \
   -uhttpd-mod-ubus \
   -odhcpd \
   -odhcp6c \
   -odhcpd-ipv6only \
   -odhcpd6c \
   -libip6tc \
   -ip6tables \
   -dnsmasq \
   -kmod-ip6tables \
   -kmod-usb-core \
   -kmod-usb-ehci \
   -kmod-usb-ledtrig-usbport \
   -kmod-usb2 \
   -wpad-mini \
   -wpad-basic-wolfssl \
   wpad \
   vnstat
   ```
