---
type: docs
title: Como usar o CephFS
---

{{< alert color="warning" title="Aviso" >}}
Este documento visa explicar a administração de diretórios, permissões e quotas
do CephFS em produção. Ele NÃO explica como criar um CephFS ou implantar MDS.
{{< /alert >}}

## Criando uma autorização

Para criar uma autorização, basta executar o seguinte comando:

```
$ ceph fs authorize cephfs client.<CLIENT_NAME> <PATH> rw
```

Onde `PATH` é o caminho onde o cliente irá escrever e `CLIENT_NAME` é o
nome do cliente (nosso padrão é utilizar `fs-<VMNAME>`).

Exemplo:

```
$ ceph fs authorize cephfs client.fs-neudokumente /dokumente rw
```

## Administrando quotas

Para definir a quota em um diretório CephFS, use:

```
$ setfattr -n ceph.quota.max_bytes -v <SIZE_IN_BYTES> <PATH>
```

Exemplo:

```
$ setfattr -n ceph.quota.max_bytes -v 500000000000 /cephfs/dokumente/ # 500GB
```

Para visualizar uma quota, use:

```
$ getfattr -n ceph.quota.max_bytes <PATH>
```

Exemplo:

```
$ getfattr -n ceph.quota.max_bytes /cephfs/dokumente/

# file: cephfs/dokumente/
ceph.quota.max_bytes="500000000000"
```

Para remover uma quota, use:

```
$ setfattr -n ceph.quota.max_bytes -v 0 <PATH>
```

Exemplo:

```
$ setfattr -n ceph.quota.max_bytes -v 0 /cephfs/dokumente/
```

## Configuração do cliente

Instale o pacote do Ceph:

```
$ apt install ceph-common
```

Gere um arquivo de configuração mínima no Ceph usando:

```
$ ceph config generate-minimal-conf
```

Copie a saída para o arquivo `/etc/ceph/ceph.conf`.
Se este arquivo/diretório não existir, crie.

Adicione a seguinte linha ao `/etc/fstab`:

```
barril.dfs:<PATH>             <MOUNT_DIR>               ceph                name=<CLIENT_NAME>,secret=<CLIENT_SECRET>,noatime,_netdev 0 2
```

Onde `PATH` é o diretório do CephFS, `MOUNT_DIR` é o path para montagem
local e `CLIENT_SECRET` é o keyring gerado na [etapa de autorização](#criando-uma-autorizacao) do Ceph.

OBS: Pode aparecer um erro de `modprobe` ao montar, mas mesmo assim ele monta.

Para verificar o espaço usado por um diretório, use o comando:

```
$ getfattr -n ceph.dir.rbytes <PATH>
```

A saída é em bytes. Você pode usar o programa `units` para converter bytes em
gigabytes através do comando `units 1000000B GiB`.
