---
type: docs
title: Instalação inicial do Ceph no primeiro servidor, barril4
---

01. incluir repositório do ceph para a versão octopus (15.2) no apt:

    ```console
    $ wget -q -O- 'https://download.ceph.com/keys/release.asc' | sudo apt-key add -
    $ cat > /etc/apt/sources.list.d/ceph.list <<EOF
    deb https://download.ceph.com/debian-octopus buster main
    EOF
    ```

02. instalar o conjunto mínimo de pacotes:

    ```console
    $ apt update
    $ apt --no-install-recommends install ceph ceph-mds
    ```

03. criar o identificador único do sistema de arquivos com uuidgen e o arquivo /etc/ceph/ceph.conf com a configuração inicial para o primeiro monitor:

    ```ini
    [global]
    fsid = c30ecc8d-440e-4608-b3fe-5020337ae11d
    mon_initial_members = barril4
    mon_host = 10.17.119.14
    ```

04. criar as chaves do ceph:

    ```console
    $ ceph-authtool --create-keyring /tmp/ceph.mon.keyring --gen-key -n mon. --cap mon 'allow *'
    $ ceph-authtool --create-keyring /etc/ceph/ceph.client.admin.keyring --gen-key -n client.admin --cap mon 'allow *' --cap osd 'allow *' --cap mds 'allow *' --cap mgr 'allow *'
    $ ceph-authtool --create-keyring /var/lib/ceph/bootstrap-osd/ceph.keyring --gen-key -n client.bootstrap-osd --cap mon 'profile bootstrap-osd' --cap mgr 'allow r'
    $ ceph-authtool /tmp/ceph.mon.keyring --import-keyring /etc/ceph/ceph.client.admin.keyring
    $ ceph-authtool /tmp/ceph.mon.keyring --import-keyring /var/lib/ceph/bootstrap-osd/ceph.keyring
    $ chown ceph:ceph /tmp/ceph.mon.keyring
    ```

05. criar o mapa para os monitores:

    ```console
    $ monmaptool --create --add barril4 10.17.119.14 --fsid c30ecc8d-440e-4608-b3fe-5020337ae11d /tmp/monmap
    ```

06. Como usuário ceph, criar o diretório de dados do monitor e colocar as chaves e o mapa:

    ```console
    $ sudo -u ceph mkdir /var/lib/ceph/mon/ceph-barril4
    $ sudo -u ceph ceph-mon --mkfs -i barril4 --monmap /tmp/monmap --keyring /tmp/ceph.mon.keyring
    ```

07. incluir as configurações adicionais no /etc/ceph/ceph.conf:

    ```ini
    [global]
    fsid = c30ecc8d-440e-4608-b3fe-5020337ae11d
    mon_initial_members = barril4
    mon_host = 10.17.119.14
    public_network = 10.17.119.0/24
    auth_cluster_required = cephx
    auth_service_required = cephx
    auth_client_required = cephx
    auth_allow_insecure_global_id_reclaim = false
    osd_pool_default_size = 3
    osd_pool_default_min_size = 1
    osd_pool_default_pg_num = 2048
    osd_pool_default_pgp_num = 2048
    osd_memory_target = 16G
    osd_crush_chooseleaf_type = 1
    ```

08. Habilitar e iniciar o monitor:

    ```console
    $ systemctl enable ceph-mon@barril4
    $ systemctl start ceph-mon@barril4
    ```

09. Verificar se funcionou:

    ```console
    $ ceph -s
    ```

    Se der `monitors have not enabled msgr2` executar:
    ```console
    $ ceph mon enable-msgr2
    $ systemctl start ceph-mon@barril4
    $ systemctl stop ceph-mon@barril4
    ```

10. criar os osd para controlar os 5 discos sata e dividir o nvme 16 partes se o relatorio estiver ok, rodar o comando novamente sem o `--report`:

    ```
    $ ceph-volume lvm batch --report /dev/sdt /dev/sdu /dev/sdv /dev/sdw /dev/sdx --db-devices /dev/nvme0n1 --block-db-slots 16
    ```

11. executar os passos 1 e 2 para a barril3

12. na barril4:

    * incluir a barril3 no /etc/ceph/ceph.conf
    * copiar o /etc/ceph para a barril3
    * copiar o /var/lib/ceph/bootstrap-osd/ceph.keyring para a barril3

13. copiar a chave do monitor de barril4:/var/lib/ceph/mon/ceph-barril4/keyring para barril3:/tmp/keyring e configurar um monitor na barril3:

    ```
    $ chown ceph:ceph /tmp/keyring
    $ sudo -u ceph mkdir /var/lib/ceph/mon/ceph-barril3
    $ sudo -u ceph ceph-mon --mkfs -i barril3 --keyring /tmp/keyring
    ```

14. ajustar e executar os passos 8, 9 e 10 para a barril3

15. ajustar e executar os passos 11, 12, 13 e 14 para barril1 e barril2

16. ajustar e executar os passos 11, 12, 13, 8 e 9 na urquell

17. configurar o gerenciador na barril4:

    ```
    $ sudo -u ceph mkdir /var/lib/ceph/mgr/ceph-barril4
    $ ceph auth get-or-create mgr.barril4 mon 'allow profile mgr' osd 'allow *' mds 'allow *' > /tmp/keyring
    $ chmod 600 /tmp/keyring
    $ chown ceph:ceph /tmp/keyring
    $ sudo -u ceph mv /tmp/keyring /var/lib/ceph/mgr/ceph-barril4/keyring
    ```

18. habilitar e iniciar o gerenciador na barril4:

    ```
    $ systemctl enable ceph-mgr@barril4
    $ systemctl start ceph-mgr@barril4
    ```

19. ajustar e executar os passos 17 e 18 para as outras máquinas
