---
title: bbb
type: docs
---

| | |
|-|-|
| **Sistema Operacional** | Ubuntu 18.04.6 LTS |
| **Kernel** | Compilado pelo c3sl - (GNU/Linux 5.10.77-minmvs x86_64) |

A máquina virtual bbb roda os serviços da [aplicação BigBlueButton](https://bigbluebutton.org/),
uma plataforma de sala de aula virtual disponível em [bbb.c3sl.ufpr.br](https://bbb.c3sl.ufpr.br).
O frontend utilizado é o Greenlight, uma aplicação separada que roda na mesma
máquina virtual usando [](/docs/concepts/docker).

## Serviços

A máquina virtual bbb roda os seguintes serviços usando [](/docs/concepts/systemd):

- nginx
- freeswitch
- redis-server
- bbb-apps-akka
- bbb-fsesl-akka
- mongod
- bbb-html5
- bbb-webrtc-sfu
- kurento-media-server
- bbb-html5-backend@1
- bbb-html5-backend@2
- bbb-html5-frontend@1
- bbb-html5-frontend@2
- etherpad
- bbb-web
- greenlight (contêiner [](/docs/concepts/docker))
- Postgres (contêiner [](/docs/concepts/docker))

É possível verificar o estado de cada serviço pelo [](/docs/concepts/systemd).
Porém, no caso da aplicação BBB, o aconselhado é utilizar o seu próprio
comando `bbb-conf --status`.

{{< alert title="Nota" >}}
O Greenlight é o frontend para o BigBlueButton, e está localizado no diretório
`/root/greenlight-v3`. É recomendável fazer dump do banco antes de mexer no
Greenlight.

```console
$ docker exec -it  postgres pg_dump -U postgres \
    -d greenlight-v3-production > bbb_greenlight_$(date -I).sql
```
{{< /alert >}}

## Configuração do firewall

A virtual está em uma única VLAN, MVC3. E as configurações de firewall atuais são:

1. Liberar a saída das portas 80 e 443 para a virtual

2. Outras portas específicas são:

   No [firewall da roble](/docs/services/roble-firewall):

   ```
   # bbb ports
   $ ipt -A FORWARD -p udp -d bbb -m multiport \
       --dports 16384:32768 -j ACCEPT
   ```

   No [firewall da estrella](/docs/services/estrella-firewall):

   ```
   chain FORWARD { ip daddr bbb.c3sl.ufpr.br udp dport 16384-65535 counter packets 0 bytes 0 accept }
   chain entra { ip saddr bbb.c3sl.ufpr.br counter packets 0 bytes 0 accept }
   chain sai { ip daddr bbb.c3sl.ufpr.br counter packets 0 bytes 0 accept }
   ```

Note que o nome da virtual é bbb, então nas regras se está utilizando `bbb`.
Para instanciar outra virtual, é necessário alterar todas ocorrências de `bbb` para o
novo nome.

## Comandos de gerência

Para verificar o estado do BigBlueButton utilize o comando:

```
$ bbb-conf --check
```

Para iniciar o BigBlueButton utilize o comando:

```
$ bbb-conf --start
```

Para parar o BigBlueButton utilize o comando:

```
$ bbb-conf --stop
```

Para reiniciar o BigBlueButton utilize o comando:

```
$ bbb-conf --restart
```

Para verificar o estado do Greenlight utilize o comando:

```
$ docker ps
```

Para iniciar o Greenlight utilize o comando:

```
$ docker-compose -f /root/greenlight/ up -d
```

Para parar o Greenlight utilize o comando:

```
$ docker-compose -f /root/greenlight/ stop
```

Para reiniciar o Greenlight, utilize o comando:

```
$ docker-compose -f /root/greenlight restart
```

## Verificar logs

Os logs do BigBlueButton normalmente ficam em `/var/log`. É possível verificar o log
de cada serviço navegando pelo diretório `/var/log`.
Também é possível verificar pelo comando:

```
$ bbb-conf --debug
```

Se quiser monitorar em tempo real faça:

```
$ bbb-conf --watch
```

O Greenlight roda dentro de [](/docs/concepts/docker), então os logs
ficam dentro do contêiner. Para ver os logs do contêiner faça:

```
$ docker-compose -f /root/greenlight logs --follow
```

Para o log do Ruby on Rails, execute o seguinte comando:

```
$ docker exec -it greenlight-v2 tail -f /usr/src/app/log/production.log
```

## Como atualizar

Atualizar d aplicação é bem simples e vamos dividir em duas partes, atualizar
o BBB e atualizar do Greenlight. O algoritmo é:

- Parar o BigBlueButton.
- Fechar o BigBlueButton no firewall.
- Atualizar a virtual.
- Rodar o script para atualizar o BigBlueButton.
- Atualizar o Greenlight.
- Alterar o `/etc/nginx/sites-available/bigbluebutton`.
- Abrir o BigBlueButton no firewall.
- Iniciar todos os serviços ou reiniciar a virtual.

### Antes de atualizar

A primeira coisa que se deve fazer antes de atualizar é parar a aplicação e
fechar a virtual no firewall. Para isso, basta tirar a virtual das
listas `http_int_allowed` e `http_int_allowed` dos
arquivos `rede/{firewall,firewall-ip}` no [](/docs/services/roble-firewall).

### Atualizar o sistema operacional

Para atualizar o sistema operacional rode os seguintes comandos:

```
$ apt update
$ apt upgrade -y
```

### Atualizar o BBB

Para atualizar o BBB entre no diretório `/root/bbb-install` na virtual bbb
e faça um `git pull`:

```
root@bbb:~/bbb-install# git pull
remote: Enumerating objects: 28, done.
remote: Counting objects: 100% (28/28), done.
remote: Compressing objects: 100% (24/24), done.
remote: Total 28 (delta 14), reused 7 (delta 4), pack-reused 0
Unpacking objects: 100% (28/28), done.
From https://github.com/bigbluebutton/bbb-install
   9f39c70..cdbf737  master     -> origin/master
Updating 9f39c70..cdbf737
Fast-forward
 README.md      | 16 +++++++++-------
 bbb-install.sh | 10 +++++-----
 2 files changed, 14 insertions(+), 12 deletions(-)
```

Agora rode o comando `bbb-install` para atualizar com a nova versão:

```
root@bbb:~/bbb-install# ./bbb-install.sh \
    -v bionic-240 -s bbb.c3sl.ufpr.br -d -v bionic-240 -g
```

## Comandos úteis

Para verificar se existe algum serviço falhado no systemd:

```
$ systemctl list-units --state=failed
```

## Problemas conhecidos

A implantação do BigBlueButton não é trivial, possui muito truques e bugs
conhecidos pela comunidade.

### Nginx e certificado SSL do C3SL

Após a atualização, o BigBlueButton sobrescreve
o arquivo `/etc/nginx/sites-available/bigbluebutton` e por
consequência é perdido a configuração de https do `https://bbb.c3sl.ufpr.br`. Portanto, para
contornar esse problema, após a cada atualização é necessário verificar o arquivo
`/etc/nginx/sites-available/bigbluebutton`, especificamente se os arquivos do ssl
estão configurados.

Para resolver basta editar o arquivo `/etc/nginx/sites-available/bigbluebutton` e acertar os
caminhos do certificado e chave privada. Os caminhos corretos são:

```
ssl_certificate /etc/ssl/certs/c3sl.pem;
ssl_certificate_key /etc/ssl/private/c3sl.pem;
```

Depois reinicie o nginx. Pode reiniciar o BBB inteiro, mas demora então vale mais a pena reiniciar
só o nginx, com:

```
$ systemctl restart nginx
```

Execute o comando `bbb-conf --restart` para reiniciar todo o bbb e para verificar se está tudo ok
utilize o comando `bbb-conf --check`.

### Serviço do FreeSWITCH falha ao iniciar

O FreeSWITCH é responsável pela comunicação por voz. [Desde a versão 2.1 existe um bug no systemd do FreeSWITCH](https://docs.bigbluebutton.org/support/troubleshooting/#freeswitch-fails-to-start-with-a-setscheduler-error) que faz com que o serviço falhe.

Para mitigar o problema, edite o arquivo `/lib/systemd/system/freeswitch.service`
e comente o seguinte conteúdo:

```
#LimitRTPRIO=infinity
#LimitRTTIME=7000000
#IOSchedulingClass=realtime
#IOSchedulingPriority=2
#CPUSchedulingPolicy=rr
#CPUSchedulingPriority=89
```

Agora execute os comandos:

```
$ systemctl daemon-reload
$ systemctl restart freeswitch
$ bbb-conf --restart
```

### Serviço bbb-webrtc-sfu falha ao iniciar

O WebRTC cuida do vídeo e [possui um problema similar ao do FreeSWITCH que
os desenvolvedores não resolvem](https://docs.bigbluebutton.org/support/troubleshooting/#bbb-webrtc-sfu-fails-to-start-with-a-setscheduler-error).

Para mitigar o problema, edite o arquivo
`/lib/systemd/system/bbb-webrtc-sfu.service` e mude as seguintes opções:

```
[Service]
CPUSchedulingPolicy=other
Nice=-10
```

Execute o comando `systemctl daemon-reload` e reinicie o
BigBlueButton com `bbb-conf --restart`.

{{< alert title="Nota" >}}
Note que [a solução sugerida pela documentação do projeto](https://docs.bigbluebutton.org/support/troubleshooting/#bbb-webrtc-sfu-fails-to-start-with-a-setscheduler-error)
não funciona. Ela consiste em criar um arquivo
em `/etc/systemd/system/bbb-webrtc-sfu.service.d/override.conf`, e assim
não precisaria se alterar o arquivo de serviço a cada nova atualização.
Porém, isso não funciona.
{{< /alert >}}
